@@ -9,12 +9,18 @@ import matplotlib.pyplot as plt
 
 import asilib
 
-mission='REGO'
-station='GILL'
+mission = 'REGO'
+station = 'GILL'
 
 fig, ax = plt.subplots(figsize=(8, 6))
-ax, im = asilib.plot_keogram(['2015-02-02T10', '2015-02-02T11'], mission, station, 
-                ax=ax, map_alt=230, pcolormesh_kwargs={'cmap':'Greys_r'})
+ax, im = asilib.plot_keogram(
+    ['2015-02-02T10', '2015-02-02T11'],
+    mission,
+    station,
+    ax=ax,
+    map_alt=230,
+    pcolormesh_kwargs={'cmap': 'Greys_r'},
+)
 plt.colorbar(im)
 plt.tight_layout()
-plt.show()
\ No newline at end of file
+plt.show()
