@@ -2,12 +2,21 @@ import matplotlib.pyplot as plt
 import matplotlib.colors as colors
 import numpy as np
 
-from asilib.io.load import get_frames, load_cal, _validate_time_range
+from asilib.io.load import _validate_time_range
 from asilib.analysis.keogram import keogram
 
 
-def plot_keogram(time_range, mission, station, map_alt=None, ax=None, color_bounds=None, 
-            color_norm='lin', title=True, pcolormesh_kwargs={}):
+def plot_keogram(
+    time_range,
+    mission,
+    station,
+    map_alt=None,
+    ax=None,
+    color_bounds=None,
+    color_norm='lin',
+    title=True,
+    pcolormesh_kwargs={},
+):
     """
     Makes a keogram along the central meridian.
 
@@ -24,8 +33,8 @@ def plot_keogram(time_range, mission, station, map_alt=None, ax=None, color_boun
     station: str
         The station id to download the data from.
     map_alt: int, optional
-        The mapping altitude, in kilometers, used to index the mapped latitude in the 
-        calibration data. If None, will plot pixel index for the y-axis.
+        The mapping altitude, in kilometers, used to index the mapped latitude in the
+        skymap calibration data. If None, will plot pixel index for the y-axis.
     ax: plt.subplot
         The subplot to plot the frame on. If None, this function will
         create one.
@@ -38,7 +47,7 @@ def plot_keogram(time_range, mission, station, map_alt=None, ax=None, color_boun
     title: bool
         Toggles a default plot title with the format "date mission-station keogram".
     pcolormesh_kwargs: dict
-        A dictionary of keyword arguments (kwargs) to pass directly into 
+        A dictionary of keyword arguments (kwargs) to pass directly into
         plt.pcolormesh. One use of this parameter is to change the colormap. For example,
         pcolormesh_kwargs = {'cmap':'tu}
 
@@ -52,11 +61,28 @@ def plot_keogram(time_range, mission, station, map_alt=None, ax=None, color_boun
     Raises
     ------
     AssertionError
-        If len(time_range) != 2. Also if map_alt does not equal the mapped 
-        altitudes in the calibration mapped values.
+        If len(time_range) != 2. Also if map_alt does not equal the mapped
+        altitudes in the skymap mapped values.
+
+    Example
+    -------
+    | import matplotlib.pyplot as plt
+    |
+    | import asilib
+    |
+    | mission='REGO'
+    | station='LUCK'
+    |
+    | fig, ax = plt.subplots(figsize=(8, 6))
+    | ax, im = asilib.plot_keogram(['2017-09-27T07', '2017-09-27T09'], mission, station,
+    |                ax=ax, map_alt=230, color_bounds=(300, 800), pcolormesh_kwargs={'cmap':'turbo'})
+    |
+    | plt.colorbar(im)
+    | plt.tight_layout()
+    | plt.show()
     """
     time_range = _validate_time_range(time_range)
-    keo_df = keogram(time_range, mission, station, map_alt)    
+    keo_df = keogram(time_range, mission, station, map_alt)
 
     if ax is None:
         _, ax = plt.subplots()
@@ -73,9 +99,15 @@ def plot_keogram(time_range, mission, station, map_alt=None, ax=None, color_boun
     else:
         raise ValueError('color_norm must be either "log" or "lin".')
 
-    im = ax.pcolormesh(keo_df.index, keo_df.columns, keo_df.to_numpy()[:-1, :-1].T, 
-                        norm=norm, shading='flat', **pcolormesh_kwargs)
+    im = ax.pcolormesh(
+        keo_df.index,
+        keo_df.columns,
+        keo_df.to_numpy()[:-1, :-1].T,
+        norm=norm,
+        shading='flat',
+        **pcolormesh_kwargs,
+    )
 
     if title:
         ax.set_title(f'{time_range[0].date()} | {mission.upper()}-{station.upper()} keogram')
-    return ax, im
\ No newline at end of file
+    return ax, im
